import glob from 'fast-glob';
import { existsSync } from 'node:fs';
import { cp, readFile } from 'node:fs/promises';
import { basename, dirname, resolve } from 'node:path';
import { join as joinPosix } from 'node:path/posix';
import { getBlobStore } from '../blob.js';
import { getPrerenderManifest } from '../config.js';
import { NEXT_DIR } from '../constants.js';
export const uploadStaticContent = async ({ constants: { NETLIFY_API_TOKEN, NETLIFY_API_HOST, SITE_ID }, }) => {
    const dir = 'server/pages';
    const paths = await glob('**/*.html', {
        cwd: resolve(NEXT_DIR, dir),
    });
    let manifest;
    let blob;
    try {
        manifest = await getPrerenderManifest();
        blob = getBlobStore({ NETLIFY_API_TOKEN, NETLIFY_API_HOST, SITE_ID });
    }
    catch (error) {
        console.error(`Unable to upload static content: ${error.message}`);
        return;
    }
    const uploads = await Promise.allSettled(paths
        .filter((path) => {
        const route = '/' + joinPosix(dirname(path), basename(path, '.html'));
        return !Object.keys(manifest.routes).includes(route);
    })
        .map(async (path) => {
        await blob.set(joinPosix(dir, path), await readFile(resolve(NEXT_DIR, dir, path), 'utf-8'));
    }));
    uploads.forEach((upload, index) => {
        if (upload.status === 'rejected') {
            console.error(`Unable to store static content: ${upload.reason.message}`);
        }
    });
};
/**
 * Move static content to the publish dir so it is uploaded to the CDN
 */
export const copyStaticAssets = async ({ constants: { PUBLISH_DIR }, }) => {
    if (existsSync(resolve('public'))) {
        await cp(resolve('public'), resolve(PUBLISH_DIR), { recursive: true, force: false });
    }
    if (existsSync(resolve(NEXT_DIR, 'static'))) {
        await cp(resolve(NEXT_DIR, 'static'), resolve(PUBLISH_DIR, '_next/static'), {
            recursive: true,
            force: false,
        });
    }
};
